@@ -23,11 +23,6 @@ QList<BugFieldValue *> BugField::values() const
     return m_values;
 }
 
-void BugField::setValues(QList<BugFieldValue *> values)
-{
-    m_values = values;
-}
-
 void BugField::registerVariantConverters()
 {
     static bool convertersRegistered = false;
@@ -39,7 +34,7 @@ void BugField::registerVariantConverters()
     QMetaType::registerConverter<QVariantList, QList<BugFieldValue *>>([](QVariantList v) -> QList<BugFieldValue *> {
         QList<BugFieldValue *> list;
         list.reserve(v.size());
-        for (const QVariant &variant : qAsConst(v)) {
+        for (const QVariant &variant : std::as_const(v)) {
             list.append(new BugFieldValue(variant.toHash()));
         }
         return list;
@@ -59,9 +54,6 @@ QString BugFieldValue::name() const
     return m_name;
 }
 
-void BugFieldValue::setName(QString name)
-{
-    m_name = name;
-}
-
 } // namespace Bugzilla
+
+#include "moc_bugfield.cpp"
