@@ -32,6 +32,7 @@
 #include "drkonqi_debug.h"
 #include "parser/backtraceparser.h"
 #include "productmapping.h"
+#include "safe_strerror.h"
 #include "sentryconnection.h"
 #include "sentryscope.h"
 #include "settings.h"
@@ -52,15 +53,6 @@ struct UnameValues {
     QString rawDescription;
 };
 
-char *safe_strerror(int error)
-{
-    constexpr auto maxBufferSize = 1024;
-    thread_local std::array<char, maxBufferSize> buffer;
-    // The return value changes depending on CFLAGS, so we intentionally do not do anything with it!
-    strerror_r(error, buffer.data(), buffer.size());
-    return buffer.data();
-}
-
 UnameValues unameValues()
 {
     struct utsname name{};
@@ -583,6 +575,7 @@ void ReportInterface::prepareCrashEvent()
     case BacktraceGenerator::NotLoaded:
     case BacktraceGenerator::Failed:
     case BacktraceGenerator::FailedToStart:
+    case BacktraceGenerator::MemoryPressure:
         break;
     }
     static bool connected = false;
@@ -778,7 +771,7 @@ ReportInterface *ReportInterface::self()
 
 bool ReportInterface::hasCrashEventSent() const
 {
-    return !isCrashEventSendingEnabled() || m_sentryPostbox.hasDelivered() || m_skipSentry;
+    return !isCrashEventSendingEnabled() || m_sentryPostbox.hasDelivered();
 }
 
 bool ReportInterface::isCrashEventSendingEnabled() const
@@ -786,7 +779,6 @@ bool ReportInterface::isCrashEventSendingEnabled() const
     qCDebug(DRKONQI_LOG) << "sentry:" << Settings::self()->sentry() //
                          << "forceSentry:" << m_forceSentry //
                          << "hasDeletedFiles:" << DrKonqi::crashedApplication()->hasDeletedFiles() //
-                         << "skipSentry:" << m_skipSentry //
                          << "targetsBugzilla:" << DrKonqi::crashedApplication()->bugReportAddress().isKdeBugzilla();
     const auto enabled = Settings::self()->sentry() || m_forceSentry;
     return enabled && !DrKonqi::crashedApplication()->hasDeletedFiles() && DrKonqi::crashedApplication()->bugReportAddress().isKdeBugzilla();
